Documentation
¶
Overview ¶
Package ethstats implements the network stats reporting service.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
Service implements an Ethereum netstats reporting daemon that pushes local chain statistics up to a monitoring server.
func (*Service) Start ¶
Start implements node.Lifecycle, starting up the monitoring and reporting daemon.
Source Files
¶
- ethstats.go
Click to show internal directories.
Click to hide internal directories.