Documentation
¶
Index ¶
Constants ¶
const ( MaxRequestLength = 16 // max number of individual requests in a batch CapacityQueryName = "cq" CapacityQueryMaxLen = 16 )
const ( IntNonNegative = iota IntNegative IntPlusInf IntMinusInf )
Variables ¶
Functions ¶
This section is empty.
Types ¶
type CapacityQueryReply ¶
type CapacityQueryReply []uint64
CapacityQueryReq is the encoding format of the response to the capacity query
type CapacityQueryReq ¶
CapacityQueryReq is the encoding format of the capacity query
type IntOrInf ¶
IntOrInf is the encoding format for arbitrary length signed integers that can also hold the values of +Inf or -Inf
func (*IntOrInf) BigInt ¶
BigInt returns the value as a big.Int or panics if the value is infinity
func (*IntOrInf) Inf ¶
Inf returns 1 if the value is +Inf, -1 if it is -Inf, 0 otherwise
func (*IntOrInf) Int64 ¶
Int64 limits the value between MinInt64 and MaxInt64 (even if it is +-Inf) and returns an int64 type
func (*IntOrInf) SetBigInt ¶
SetBigInt sets the value to the given big.Int
type Request ¶
Request describes a single vflux request inside a batch. Service and request type are identified by strings, parameters are RLP encoded.
Source Files
¶
- requests.go